# CyCoDa: GPU-accelerated compositional data analysis

A lot of these functions have been adapted from the [pycodamath](https://bitbucket.org/genomicepidemiology/pycodamath/) package developed by Christian Brinch.